@@ -4,12 +4,13 @@ use strict;
 use base 'DBIx::dbMan::Extension';
 use Text::FormatTable;
 use DBI;
+use Term::ANSIColor;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 1;
 
-sub IDENTIFICATION { return "000001-000005-000010"; }
+sub IDENTIFICATION { return "000001-000005-000011"; }
 
 sub preference { return 0; }
 
@@ -186,7 +187,7 @@ sub handle_action {
 			$action{output} = $clist;
 		} elsif ($action{operation} eq 'create') {
 			my %parm = ();
-			for (qw/driver dsn login password auto_login config/) { $parm{$_} = $action{$_} || ''; }
+			for (qw/driver dsn login password auto_login config prompt_color/) { $parm{$_} = $action{$_} || ''; }
 
 			$action{action} = 'NONE';
 			my $error = $obj->{-dbi}->create_connection($action{what},\%parm);
@@ -232,7 +233,11 @@ sub handle_action {
 		}
 
 		my $db = '';
-		$db = '<'.$obj->{-dbi}->current.'>' if $obj->{-dbi}->current;
+		if ( $obj->{-dbi}->current ) {
+			$db .= color( $obj->{-dbi}->prompt_color ) if $obj->{-dbi}->prompt_color;
+			$db .= '<'.$obj->{-dbi}->current.'>';
+			$db .= color( 'reset' ) if $obj->{-dbi}->prompt_color;
+		}
 		$obj->{-interface}->prompt($obj->{prompt_num},$db);
 	}
 
